@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE DataKinds, PolyKinds, UnicodeSyntax, GADTs, NoImplicitPrelude,
              TypeOperators, TypeFamilies #-}
 {-# OPTIONS_GHC -fno-warn-unticked-promoted-constructors #-}
@@ -21,7 +20,8 @@ data Vec ∷ ℕ → Type → Type where
   (:>) ∷ a → Vec n a → Vec (S n) a
 infixr 8 :>
 
-type family (x ∷ Vec n a) ++ (y ∷ Vec m a) ∷ Vec (n + m) a where
+type (++) ∷ Vec n a → Vec m a → Vec (n + m) a
+type family x ++ y where
   Nil       ++ y = y
   (x :> xs) ++ y = x :> (xs ++ y)
 infixl 5 ++
