@@ -27,7 +27,7 @@ foreign import ccall unsafe "head_bytearray"
   c_head_bytearray :: MutableByteArray# RealWorld -> IO Word8
 
 data Box :: Type where
-  Box :: (Any :: TYPE 'UnliftedRep) -> Box
+  Box :: (Any :: TYPE ('BoxedRep 'Unlifted)) -> Box
 
 data MutableByteArray :: Type where
   MutableByteArray :: MutableByteArray# RealWorld -> MutableByteArray
@@ -38,8 +38,9 @@ box (MutableByteArray x) = Box (unsafeCoerce# x)
 
 luckySingleton :: IO MutableByteArray
 luckySingleton = IO $ \s0 -> case newByteArray# 1# s0 of
-  (# s1, marr# #) -> case writeWord8Array# marr# 0# 42## s1 of
+  (# s1, marr# #) -> case writeWord8Array# marr# 0# fortyTwo s1 of
     s2 -> (# s2, MutableByteArray marr# #)
+  where W8# fortyTwo = 42
 
 readByteArray :: MutableByteArray -> Int -> IO Word8
 readByteArray (MutableByteArray b#) (I# i#) = IO $ \s0 ->
