@@ -3,12 +3,6 @@
 
 #include "MachDeps.h"
 
-#if WORD_SIZE_IN_BITS < 64
-#define WW Word64
-#else
-#define WW Word
-#endif
-
 module Obj where
 
 import GHC.Exts
