@@ -13,7 +13,7 @@ import GHC (GhcPs)
 testMe :: HsExpr GhcPs -> Int
 testMe (HsVar a b) = _
 testMe (HsUnboundVar xuv uv) = _
-testMe (HsOverLabel xol s m_ip) = _
+testMe (HsOverLabel xol m_ip) = _
 testMe (HsIPVar xv hin) = _
 testMe (HsOverLit xole hol) = _
 testMe (HsLit xle hl) = _
