@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# Language RankNTypes #-}
 {-# Language TypeApplications #-}
 {-# Language DataKinds        #-}
@@ -6,13 +5,15 @@
 {-# Language GADTs            #-}
 {-# Language TypeFamilies     #-}
 
+module T15787 where
+
 import Data.Kind
 
 class Ríki (ob :: Type) where
  type Hom :: ob -> ob -> Type
 
-data
-  Kl_kind :: forall ob . (ob -> ob) -> ob -> Type where
+type Kl_kind :: forall ob . (ob -> ob) -> ob -> Type
+data Kl_kind m k where
   Kl      :: k -> Kl_kind (m :: ob -> ob) k
 
 type family
