@@ -1,13 +1,19 @@
 {-# LANGUAGE LambdaCase #-}
 
+-- Lambda
+bar = g >>= \foo -> 10
+
+-- \case
 foo = f >>= \case
         Just h -> loadTestDB (h ++ "/.testdb")
         Nothing -> fmap S.Right initTestDB
 
+-- \cases
 foo = f >>= \cases
         x (Just h) -> loadTestDB (h ++ "/.testdb")
         _ Nothing -> fmap S.Right initTestDB
 
+-- \cases with guards
 foo = f >>= \cases
         | a -> loadTestDB (h ++ "/.testdb")
         | b -> fmap S.Right initTestDB
@@ -17,3 +23,5 @@ foo = f >>= \cases
 isAlarmSetSTM :: AlarmClock -> STM Bool
 isAlarmSetSTM AlarmClock{..} = readTVar acNewSetting
   >>= \case { AlarmNotSet -> readTVar acIsSet; _ -> return True }
+
+bar = g >>= \foo -> 10
