@@ -5,7 +5,7 @@
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE UnboxedTuples #-}
 
-module RepPolyTuple2 where
+module Main where
 
 import GHC.Exts
 
@@ -16,6 +16,12 @@ type family F where { F = Float# }
 
 {-# NOINLINE expensive #-}
 expensive :: Float -> Float
-expensive x = cos x ** 123.45
+expensive x = cos x ** 0.5
 
+{-# NOINLINE tup #-}
 tup x = (# , #) @LiftedRep @RR (expensive x)
+
+showTup (# x, y #) = show x ++ " " ++ show (F# y)
+
+main :: IO ()
+main = print $ showTup (tup 5.0 3.0#)
