@@ -2,6 +2,6 @@
 #include <unistd.h>
 
 int main(int argc, char *argv[]) {
-    char * T7037_CONST args[2] = {"T7037", NULL};
+    char * args[2] = {"T7037", NULL};
     execv("./T7037", args);
 }
