@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE TemplateHaskell, DataKinds, PolyKinds
              , TypeApplications, TypeFamilies  #-}
 
@@ -6,7 +5,8 @@ module T12045TH1 where
 import Data.Kind
 import Language.Haskell.TH hiding (Type)
 
-$([d| type family F (a :: k) :: Type where
+$([d| type F :: k -> Type
+      type family F a where
                      F @Type Int = Bool
                      F @(Type->Type) Maybe = Char |])
 
