@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE DataKinds #-}
@@ -8,7 +7,8 @@ module T14366 where
 import Data.Kind
 import Data.Type.Equality
 
-type family Cast (a :: Type) (b :: Type) (e :: a :~: b) (x :: a) :: b where
+type Cast :: forall a b -> (a :~: b) -> (a -> b)
+type family Cast a b e x where
   Cast _ _ Refl x = x
 
 type family F (a :: Type) :: Type where
